==> todomod-1.7.tar.bz2: todomod/xoops_version.php <==
<?php
// ⥸塼ܾ
$modversion['name'] = _MI_TODOMOD_NAME; // ⥸塼̾
$modversion['version'] = 1.7; // С
$modversion['description'] = _MI_TODOMOD_DESC; // ⥸塼
$modversion['credits'] = "Keiichi Maeda (keiichi@cameo.plala.or.jp)"; // ⥸塼κ
$modversion['help'] = "todomod.html"; // إץե̤ѡ
$modversion['license'] = "GPL see LICENSE"; // 饤
$modversion['official'] = 0; // ⥸塼01
$modversion['image'] = "images/todomod_icon.png"; // 
$modversion['dirname'] = "todomod"; // ѥǥ쥯ȥ̾

// SQLե
$modversion['sqlfile']['mysql'] = "sql/mysql.sql";
// ơ֥̾
$modversion['tables'][0] = "todomod_task";
$modversion['tables'][1] = "todomod_trash_task";
// ⥸塼Ѵ̡ʤ1ʤ0
$modversion['hasAdmin'] = 1;

// ƥץ졼ȥե
$modversion['templates'][1]['file'] = 'todomod_index.html';
$modversion['templates'][1]['description'] = '';

// ᥤ󥳥ƥġʤ1ʤ0
$modversion['hasMain'] = 1;

$modversion['sub'][1]['name'] = _MI_TODOMOD_VIEWTRASHBOX;
$modversion['sub'][1]['url'] = "index.php?mode=trashbox";

$modversion['adminindex'] = 'admin/index.php';

// ǽʤ1ʤ0
$modversion['hasSearch'] = 0;


// ⥸塼ꥪץ

//ɽ륿ο
$modversion['config'][1] = array(
      'name'        => 'list_num_default', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_LISTNUM_DEFAULT', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
      'options'     => array('3' => 3, '5' => 5, '8' => 8, '10' => 10, '15' => 15, '20' => 20, '30' => 30), // ǽץ
);

//(Ȣ)ɽ륿ο
$modversion['config'][2] = array(
      'name'        => 'list_num_trashbox', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_LISTNUM_TRASHBOX', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
      'options'     => array('3' => 3, '5' => 5, '8' => 8, '10' => 10, '15' => 15, '20' => 20, '30' => 30), // ǽץ
);

//(Ȣ)ɽ륿ο
$modversion['config'][3] = array(
      'name'        => 'list_num_block', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_LISTNUM_BLOCK', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
      'options'     => array('3' => 3, '5' => 5, '8' => 8, '10' => 10, '15' => 15, '20' => 20, '30' => 30), // ǽץ
);

//ơԽĤ륰롼
$modversion['config'][4] = array(
      'name'        => 'edit_authgrp', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_EDIT_AUTHGRP', // ̾
      'description' => '_MI_TODOMOD_EDIT_AUTHGRP_DISC', // 
      'formtype'    => 'group_multi', // ե
      'valuetype'   => 'array', // ǡ
      'default'	    => array(1,2), // ǥե
);



//̤Ͽ桼ˤơԽĤ
$modversion['config'][5] = array(
      'name'        =>  'anonpost', // ѥ᡼̾
      'title'       =>  '_MI_TODOMOD_ANONPOST', // ̾
      'description' =>  '', // 
      'formtype'    =>  'yesno', // ե
      'valuetype'   =>  'int', // ǡ
      'default'     =>  0, // ǥե
);

//ȥեβ
$modversion['config'][6] = array(
      'name'        => 'title_width', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_TITLE_WIDTH', // ̾
      'description' => '', // 
      'formtype'    => 'textbox', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 78, // ǥե
);

//ܺ٥եβ
$modversion['config'][7] = array(
      'name'        => 'detail_width', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_DETAIL_WIDTH', // ̾
      'description' => '', // 
      'formtype'    => 'textbox', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 67, // ǥե
);

//ܺ٥եν
$modversion['config'][8] = array(
      'name'        => 'detail_length', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_DETAIL_LENGTH', // ̾
      'description' => '', // 
      'formtype'    => 'textbox', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
);

//֥å
$modversion['blocks'][1]['file'] = 'todolist.php';
$modversion['blocks'][1]['name'] = _MI_TODOMOD_BLOCK_NAME;
$modversion['blocks'][1]['description'] = _MI_TODOMOD_BLOCK_DESC;
$modversion['blocks'][1]['show_func'] = "b_todolist_show";
$modversion['blocks'][1]['edit_func'] = "b_todolist_edit";
$modversion['blocks'][1]['options'] = 	'|||||||show_block_title|show_block_deadline|show_block_priority|show_block_status';
$modversion['blocks'][1]['template'] = 'todomod_block_index.html';
?>

==> todomod-2.0.tar.bz2: todomod/xoops_version.php <==
<?php

// ⥸塼ܾ
$modversion['name'] = _MI_TODOMOD_NAME; // ⥸塼̾
$modversion['version'] = 2.0; // С
$modversion['description'] = _MI_TODOMOD_DESC; // ⥸塼
$modversion['credits'] = "Keiichi Maeda (keiichi@cameo.plala.or.jp)"; // ⥸塼κ
$modversion['help'] = "todomod.html"; // إץե̤ѡ
$modversion['license'] = "GPL see LICENSE"; // 饤
$modversion['official'] = 0; // ⥸塼01
$modversion['image'] = "images/todomod_icon.png"; // 
$modversion['dirname'] = "todomod"; // ѥǥ쥯ȥ̾

// SQLե
$modversion['sqlfile']['mysql'] = "sql/mysql.sql";
// ơ֥̾
$modversion['tables'][0] = "todomod_task";
$modversion['tables'][1] = "todomod_trash_task";
// ⥸塼Ѵ̡ʤ1ʤ0
$modversion['hasAdmin'] = 1;

// ƥץ졼ȥե
$modversion['templates'][1]['file'] = 'todomod_index.html';
$modversion['templates'][1]['description'] = '';

// ᥤ󥳥ƥġʤ1ʤ0
$modversion['hasMain'] = 1;

$modversion['sub'][1]['name'] = _MI_TODOMOD_VIEWTRASHBOX;
$modversion['sub'][1]['url'] = "index.php?mode=trashbox";

$modversion['adminindex'] = 'admin/index.php';

// ǽʤ1ʤ0
$modversion['hasSearch'] = 0;


// ⥸塼ꥪץ

//ɽ륿ο
$modversion['config'][1] = array(
      'name'        => 'list_num_default', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_LISTNUM_DEFAULT', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
      'options'     => array('3' => 3, '5' => 5, '8' => 8, '10' => 10, '15' => 15, '20' => 20, '30' => 30), // ǽץ
);

//(Ȣ)ɽ륿ο
$modversion['config'][2] = array(
      'name'        => 'list_num_trashbox', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_LISTNUM_TRASHBOX', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
      'options'     => array('3' => 3, '5' => 5, '8' => 8, '10' => 10, '15' => 15, '20' => 20, '30' => 30), // ǽץ
);

//(Ȣ)ɽ륿ο
$modversion['config'][3] = array(
      'name'        => 'list_num_block', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_LISTNUM_BLOCK', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
      'options'     => array('3' => 3, '5' => 5, '8' => 8, '10' => 10, '15' => 15, '20' => 20, '30' => 30), // ǽץ
);

//ơԽĤ륰롼
$modversion['config'][4] = array(
      'name'        => 'edit_authgrp', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_EDIT_AUTHGRP', // ̾
      'description' => '_MI_TODOMOD_EDIT_AUTHGRP_DISC', // 
      'formtype'    => 'group_multi', // ե
      'valuetype'   => 'array', // ǡ
      'default'	    => array(1,2), // ǥե
);



//̤Ͽ桼ˤơԽĤ
$modversion['config'][5] = array(
      'name'        =>  'anonpost', // ѥ᡼̾
      'title'       =>  '_MI_TODOMOD_ANONPOST', // ̾
      'description' =>  '', // 
      'formtype'    =>  'yesno', // ե
      'valuetype'   =>  'int', // ǡ
      'default'     =>  0, // ǥե
);

//ȥեβ
$modversion['config'][6] = array(
      'name'        => 'title_width', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_TITLE_WIDTH', // ̾
      'description' => '', // 
      'formtype'    => 'textbox', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 78, // ǥե
);

//ܺ٥եβ
$modversion['config'][7] = array(
      'name'        => 'detail_width', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_DETAIL_WIDTH', // ̾
      'description' => '', // 
      'formtype'    => 'textbox', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 67, // ǥե
);

//ܺ٥եν
$modversion['config'][8] = array(
      'name'        => 'detail_length', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_DETAIL_LENGTH', // ̾
      'description' => '', // 
      'formtype'    => 'textbox', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 10, // ǥե
);

$modversion['config'][9] = array(
      'name'        => 'wait_time', // ѥ᡼̾
      'title'       => '_MI_TODOMOD_WAIT_TIME', // ̾
      'description' => '', // 
      'formtype'    => 'select', // ե
      'valuetype'   => 'int', // ǡ
      'default'     => 1, // ǥե
      'options'     => array('0' => 0, '1' => 1, '2' => 2, '3' => 3, '4' => 4, '5' => 5), // ǽץ
);
				    
//֥å
$modversion['blocks'][1]['file'] = 'todolist.php';
$modversion['blocks'][1]['name'] = _MI_TODOMOD_BLOCK_NAME;
$modversion['blocks'][1]['description'] = _MI_TODOMOD_BLOCK_DESC;
$modversion['blocks'][1]['show_func'] = "b_todolist_show";
$modversion['blocks'][1]['edit_func'] = "b_todolist_edit";
$modversion['blocks'][1]['options'] = 	'|||||||show_block_title|show_block_deadline|show_block_priority|show_block_status';
$modversion['blocks'][1]['template'] = 'todomod_block_index.html';

//
$modversion['hasSearch'] = 1;
$modversion['search']['file'] = "include/search.inc.php";
$modversion['search']['func'] = "todo_search";

?>
